sequencetools.get_sequence_elements_at_indices
==============================================

.. autofunction:: abjad.tools.sequencetools.get_sequence_elements_at_indices.get_sequence_elements_at_indices
